@@ -154,10 +154,7 @@ void _verifyEntry(const char* name, const char* key, const char* val,
             std::dynamic_pointer_cast<CacheableString>(regPtr->get(keyPtr));
 
         ASSERT(checkPtr != nullptr, "Value Ptr should not be null.");
-        char buf[1024];
-        sprintf(buf, "In verify loop, get returned %s for key %s",
-                checkPtr->value().c_str(), key);
-        LOG(buf);
+        LOG("In verify loop, get returned " + checkPtr->value() + " for key " + key);
         if (strcmp(checkPtr->value().c_str(), value) != 0) {
           testValueCnt++;
         } else {
@@ -659,18 +656,18 @@ DUNIT_TASK_DEFINITION(CLIENT1, VerifyPutAllWithLongKeyAndStringValue)
              "putAll entry with long key and long value Mismatch.");
     }
     map0.clear();
-    const char* vals[] = {"Value-100", "Value-200"};
+    const char* customVals[] = {"Value-100", "Value-200"};
 
     for (int i = 80; i < 82; i++) {
       map0.emplace(CacheableInt64::create(i),
-                   CacheableString::create(vals[i - 80]));
+                   CacheableString::create(customVals[i - 80]));
     }
     regPtr0->putAll(map0, std::chrono::seconds(15),
                     CacheableInt32::create(1000));
     for (int i = 80; i < 82; i++) {
       auto checkPtr = std::dynamic_pointer_cast<CacheableString>(
           regPtr0->get(CacheableInt64::create(i)));
-      ASSERT(strcmp(checkPtr->value().c_str(), vals[i - 80]) == 0,
+      ASSERT(strcmp(checkPtr->value().c_str(), customVals[i - 80]) == 0,
              "putAll entry with long key and string value  Mismatch");
     }
 
