@@ -30,7 +30,6 @@
 #include <geode/TypeRegistry.hpp>
 #include <geode/internal/geode_globals.hpp>
 
-#include "AdminRegion.hpp"
 #include "CachePerfStats.hpp"
 #include "ClientProxyMembershipIDFactory.hpp"
 #include "DistributedSystem.hpp"
@@ -93,16 +92,10 @@ class APACHE_GEODE_EXPORT CacheImpl {
   void setClientCrashTEST();
 
   // For PrSingleHop C++unit testing.
-  void setNetworkHopFlag(bool networkhopflag) {
-    m_networkhop = networkhopflag;
-  };
+  void setNetworkHopFlag(bool networkhopflag) { m_networkhop = networkhopflag; }
 
   bool getAndResetNetworkHopFlag() { return m_networkhop.exchange(false); }
 
-  int getBlackListBucketTimeouts() { return m_blacklistBucketTimeout; }
-
-  void incBlackListBucketTimeouts() { ++m_blacklistBucketTimeout; }
-
   int8_t getAndResetServerGroupFlag() { return m_serverGroupFlag.exchange(0); }
 
   void setServerGroupFlag(int8_t serverGroupFlag) {
@@ -175,7 +168,6 @@ class APACHE_GEODE_EXPORT CacheImpl {
    * full path starting at a root.
    *
    * @param path the path to the region
-   * @param[out] rptr the region pointer that is returned
    * @return the Region or null if not found
    * @throws IllegalArgumentException if path is null, the empty string, or "/"
    */
@@ -185,9 +177,6 @@ class APACHE_GEODE_EXPORT CacheImpl {
    * Returns a set of root regions in the cache. Does not cause any
    * shared regions to be mapped into the cache. This set is a snapshot and
    * is not backed by the Cache. The regions passed in are cleared.
-   *
-   * @param regions the region collection object containing the returned set of
-   * regions when the function returns
    */
   std::vector<std::shared_ptr<Region>> rootRegions();
 
@@ -241,7 +230,7 @@ class APACHE_GEODE_EXPORT CacheImpl {
    */
   void readyForEvents();
 
-  static bool isPoolInMultiuserMode(std::shared_ptr<Region> regionPtr);
+  bool isPoolInMultiuserMode(const Region& region) const;
 
   //  TESTING: Durable clients. Not thread safe.
   bool getEndpointStatus(const std::string& endpoint);
@@ -309,8 +298,8 @@ class APACHE_GEODE_EXPORT CacheImpl {
   virtual DataInput createDataInput(const uint8_t* buffer, size_t len,
                                     Pool* pool) const;
 
-  PdxInstanceFactory createPdxInstanceFactory(
-      const std::string& className) const;
+  PdxInstanceFactory createPdxInstanceFactory(const std::string& className,
+                                              bool expectDomainClass) const;
 
   AuthenticatedView createAuthenticatedView(
       std::shared_ptr<Properties> userSecurityProperties,
@@ -320,7 +309,6 @@ class APACHE_GEODE_EXPORT CacheImpl {
 
  private:
   std::atomic<bool> m_networkhop;
-  std::atomic<int> m_blacklistBucketTimeout;
   std::atomic<int8_t> m_serverGroupFlag;
   bool m_ignorePdxUnreadFields;
   bool m_readPdxSerialized;
