@@ -240,7 +240,7 @@ std::shared_ptr<CqAttributes> CqQueryImpl::getCqAttributes() const {
 void CqQueryImpl::cleanup() { removeFromCqMap(); }
 
 /**
- * @return Returns the cqListeners.
+ * @param cqListener - on success, refers to the current listener
  */
 void CqQueryImpl::getCqListeners(
     CqAttributes::listener_container_type& cqListener) {
@@ -385,7 +385,7 @@ std::shared_ptr<CqResults> CqQueryImpl::executeWithInitialResults(
   GfErrType err = GF_NOERR;
   err = m_tccdm->sendSyncRequest(msg, reply);
   if (err != GF_NOERR) {
-    LOGDEBUG("CqQueryImpl::executeCqWithInitialResults errorred!!!!");
+    LOGDEBUG("CqQueryImpl::executeCqWithInitialResults failed!!!!");
     throwExceptionIfError("CqQuery::executeCqWithInitialResults:", err);
   }
   if (reply.getMessageType() == TcrMessage::EXCEPTION ||
@@ -545,7 +545,10 @@ void CqQueryImpl::updateStats(CqEvent& cqEvent) {
     case CqOperation::OP_TYPE_DESTROY:
       stats->incNumDeletes();
       break;
-    default:
+    case CqOperation::OP_TYPE_INVALID:
+    case CqOperation::OP_TYPE_INVALIDATE:
+    case CqOperation::OP_TYPE_REGION_CLEAR:
+    case CqOperation::OP_TYPE_MARKER:
       break;
   }
 }
