@@ -64,12 +64,12 @@ std::shared_ptr<CacheLoader> RegionAttributes::getCacheLoader() const {
     if (CacheXmlParser::managedCacheLoaderFn_ &&
         m_cacheLoaderFactory.find('.') != std::string::npos) {
       // this is a managed library
-      m_cacheLoader.reset((CacheXmlParser::managedCacheLoaderFn_)(
-          m_cacheLoaderLibrary.c_str(), m_cacheLoaderFactory.c_str()));
+      m_cacheLoader.reset((
+          CacheXmlParser::managedCacheLoaderFn_)(m_cacheLoaderLibrary.c_str(),
+                                                 m_cacheLoaderFactory.c_str()));
     } else {
-      CacheLoader* (*funcptr)();
-      funcptr = reinterpret_cast<CacheLoader* (*)()>(Utils::getFactoryFunction(
-          m_cacheLoaderLibrary, m_cacheLoaderFactory));
+      auto funcptr = Utils::getFactoryFunction<CacheLoader*()>(
+          m_cacheLoaderLibrary, m_cacheLoaderFactory);
       m_cacheLoader.reset(funcptr());
     }
   }
@@ -81,12 +81,12 @@ std::shared_ptr<CacheWriter> RegionAttributes::getCacheWriter() const {
     if (CacheXmlParser::managedCacheWriterFn_ &&
         m_cacheWriterFactory.find('.') != std::string::npos) {
       // this is a managed library
-      m_cacheWriter.reset((CacheXmlParser::managedCacheWriterFn_)(
-          m_cacheWriterLibrary.c_str(), m_cacheWriterFactory.c_str()));
+      m_cacheWriter.reset((
+          CacheXmlParser::managedCacheWriterFn_)(m_cacheWriterLibrary.c_str(),
+                                                 m_cacheWriterFactory.c_str()));
     } else {
-      CacheWriter* (*funcptr)();
-      funcptr = reinterpret_cast<CacheWriter* (*)()>(Utils::getFactoryFunction(
-          m_cacheWriterLibrary, m_cacheWriterFactory));
+      auto funcptr = Utils::getFactoryFunction<CacheWriter*()>(
+          m_cacheWriterLibrary, m_cacheWriterFactory);
       m_cacheWriter.reset(funcptr());
     }
   }
@@ -98,13 +98,14 @@ std::shared_ptr<CacheListener> RegionAttributes::getCacheListener() const {
     if (CacheXmlParser::managedCacheListenerFn_ &&
         m_cacheListenerFactory.find('.') != std::string::npos) {
       // this is a managed library
-      m_cacheListener.reset((CacheXmlParser::managedCacheListenerFn_)(
-          m_cacheListenerLibrary.c_str(), m_cacheListenerFactory.c_str()));
+      m_cacheListener.reset(
+          (CacheXmlParser::managedCacheListenerFn_)(m_cacheListenerLibrary
+                                                        .c_str(),
+                                                    m_cacheListenerFactory
+                                                        .c_str()));
     } else {
-      CacheListener* (*funcptr)();
-      funcptr =
-          reinterpret_cast<CacheListener* (*)()>(Utils::getFactoryFunction(
-              m_cacheListenerLibrary, m_cacheListenerFactory));
+      auto funcptr = Utils::getFactoryFunction<CacheListener*()>(
+          m_cacheListenerLibrary, m_cacheListenerFactory);
       m_cacheListener.reset(funcptr());
     }
   }
@@ -117,14 +118,13 @@ std::shared_ptr<PartitionResolver> RegionAttributes::getPartitionResolver()
     if (CacheXmlParser::managedPartitionResolverFn_ &&
         m_partitionResolverFactory.find('.') != std::string::npos) {
       // this is a managed library
-      m_partitionResolver.reset((CacheXmlParser::managedPartitionResolverFn_)(
-          m_partitionResolverLibrary.c_str(),
-          m_partitionResolverFactory.c_str()));
+      m_partitionResolver.reset((
+          CacheXmlParser::
+              managedPartitionResolverFn_)(m_partitionResolverLibrary.c_str(),
+                                           m_partitionResolverFactory.c_str()));
     } else {
-      PartitionResolver* (*funcptr)();
-      funcptr =
-          reinterpret_cast<PartitionResolver* (*)()>(Utils::getFactoryFunction(
-              m_partitionResolverLibrary, m_partitionResolverFactory));
+      auto funcptr = Utils::getFactoryFunction<PartitionResolver*()>(
+          m_partitionResolverLibrary, m_partitionResolverFactory);
       m_partitionResolver.reset(funcptr());
     }
   }
@@ -137,13 +137,14 @@ std::shared_ptr<PersistenceManager> RegionAttributes::getPersistenceManager()
     if (CacheXmlParser::managedPersistenceManagerFn_ &&
         m_persistenceFactory.find('.') != std::string::npos) {
       // this is a managed library
-      m_persistenceManager.reset((CacheXmlParser::managedPersistenceManagerFn_)(
-          m_persistenceLibrary.c_str(), m_persistenceFactory.c_str()));
+      m_persistenceManager.reset(
+          (CacheXmlParser::managedPersistenceManagerFn_)(m_persistenceLibrary
+                                                             .c_str(),
+                                                         m_persistenceFactory
+                                                             .c_str()));
     } else {
-      PersistenceManager* (*funcptr)();
-      funcptr =
-          reinterpret_cast<PersistenceManager* (*)()>(Utils::getFactoryFunction(
-              m_persistenceLibrary, m_persistenceFactory));
+      auto funcptr = Utils::getFactoryFunction<PersistenceManager*()>(
+          m_persistenceLibrary, m_persistenceFactory);
       m_persistenceManager.reset(funcptr());
     }
   }
